==> koshoten.net-2.1.2.tar.gz: koshoten-net/admin/includes/languages/japanese/orders.php <==
<?php
/*
  $Id: orders.php,v 1.1.1.1 2005/06/30 05:04:08 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2002 osCommerce

  Released under the GNU General Public License
  
  modified for Koshoten.net2
  http://www.koshoten.net/
*/

define('HEADING_TITLE', 'ʸ');
define('HEADING_TITLE_SEARCH', 'ʸID:');
define('HEADING_TITLE_STATUS', 'ơ:');

define('TABLE_HEADING_COMMENTS', '');
define('TABLE_HEADING_CUSTOMERS', 'ܵ̾');
define('TABLE_HEADING_ORDER_TOTAL', 'ʸ');
define('TABLE_HEADING_DATE_PURCHASED', 'ʸ');
define('TABLE_HEADING_STATUS', 'ơ');
define('TABLE_HEADING_ACTION', '');
define('TABLE_HEADING_QUANTITY', '');
define('TABLE_HEADING_PRODUCTS_MODEL', 'No.');
define('TABLE_HEADING_PRODUCTS', ' / ̾');
define('TABLE_HEADING_TAX', 'Ψ');
define('TABLE_HEADING_TOTAL', '');
define('TABLE_HEADING_STATUS', 'ơ');
define('TABLE_HEADING_PRICE_EXCLUDING_TAX', '()');
define('TABLE_HEADING_PRICE_INCLUDING_TAX', '(ǹ)');
define('TABLE_HEADING_TOTAL_EXCLUDING_TAX', '()');
define('TABLE_HEADING_TOTAL_INCLUDING_TAX', '(ǹ)');

define('TABLE_HEADING_STATUS', 'ơ');
define('TABLE_HEADING_CUSTOMER_NOTIFIED', 'ܵҤ');
define('TABLE_HEADING_DATE_ADDED', '');

define('ENTRY_CUSTOMER', 'ܵ̾:');
define('ENTRY_SOLD_TO', 'ʸ̾:');
define('ENTRY_STREET_ADDRESS', '꣱:');
define('ENTRY_SUBURB', 'ꣲ:');
define('ENTRY_CITY', 'ԶĮ¼:');
define('ENTRY_POST_CODE', '͹ֹ:');
define('ENTRY_STATE', 'ƻܸ:');
define('ENTRY_COUNTRY', '̾:');
define('ENTRY_TELEPHONE', 'ֹ:');
define('ENTRY_EMAIL_ADDRESS', 'E-Mail ɥ쥹:');
define('ENTRY_DELIVERY_TO', ':');
define('ENTRY_SHIP_TO', ':');
define('ENTRY_SHIPPING_ADDRESS', ':');
define('ENTRY_BILLING_ADDRESS', ':');
define('ENTRY_PAYMENT_METHOD', 'ʧˡ:');
define('ENTRY_CREDIT_CARD_TYPE', '쥸åȥɼ:');
define('ENTRY_CREDIT_CARD_OWNER', '쥸åȥɽͭ:');
define('ENTRY_CREDIT_CARD_NUMBER', '쥸åȥֹ:');
define('ENTRY_CREDIT_CARD_EXPIRES', '쥸åȥͭ:');
define('ENTRY_SUB_TOTAL', ':');
define('ENTRY_TAX', 'Ƕ:');
define('ENTRY_SHIPPING', ':');
define('ENTRY_TOTAL', ':');
define('ENTRY_DATE_PURCHASED', 'ʸ:');
define('ENTRY_STATUS', 'ơ:');
define('ENTRY_DATE_LAST_UPDATED', ':');
define('ENTRY_NOTIFY_CUSTOMER', 'Ƥ򤪵ͤ˥᡼:');
define('ENTRY_NOTIFY_COMMENTS', 'Ȥɲ:');
define('ENTRY_PRINTABLE', 'Ǽʽץ');

define('TEXT_INFO_HEADING_DELETE_ORDER', 'ʸ');
define('TEXT_INFO_DELETE_INTRO', 'ˤʸޤ?');
define('TEXT_INFO_RESTOCK_PRODUCT_QUANTITY', '߸˿򸵤᤹'); // 'Restock product quantity'
define('TEXT_DATE_ORDER_CREATED', 'ʸ:');
define('TEXT_DATE_ORDER_LAST_MODIFIED', ':');
define('TEXT_INFO_PAYMENT_METHOD', 'ʧˡ:');

define('TEXT_ALL_ORDERS', 'Ƥʸ');
define('TEXT_NO_ORDER_HISTORY', 'ʸϤޤ');

define('EMAIL_SEPARATOR', '--------------------------------------------------------------------------------');
define('EMAIL_TEXT_SUBJECT', 'ʸվΤΤ餻');
define('EMAIL_TEXT_ORDER_NUMBER', 'ʸֹ:');
define('EMAIL_TEXT_INVOICE_URL', 'ʸˤĤƤξ򲼵URLǤˤʤޤ' . "\n");
define('EMAIL_TEXT_DATE_ORDERED', 'ʸ:');
define('EMAIL_TEXT_STATUS_UPDATE',
'ʸμվϼΤ褦ʤäƤޤ' . "\n"
.'ߤμվ: [ %s ]' . "\n\n");
define('EMAIL_TEXT_COMMENTS_UPDATE', '[Ϣ]' . "\n%s");
define('EMAIL_HONORIFIC', ' ');

define('ERROR_ORDER_DOES_NOT_EXIST', '顼: ʸ¸ߤޤ');
define('SUCCESS_ORDER_UPDATED', ': ʸ֤ޤ');
define('WARNING_ORDER_NOT_UPDATED', 'ٹ: ʸ֤ϤʤˤѹޤǤ');

// Add Japanese osCommerce
define('EMAIL_TEXT_STORE_CONFIRMATION', ' ؤΤʸˤ꤬Ȥޤ' . "\n\n"
.'ʸμվڤӤϢ򡢲ˤ⿽夲ޤ');
define('EMAIL_TEXT_STORE_CONFIRMATION_FOOTER', 
'վ˴ؤƤޤ顢ŹˤϢĺޤ褦ꤤ' . "\n"
.'夲ޤ' . "\n\n");

define('ENTRY_EMAIL_ORDER_AUTO_REPLY', 'ưۿ᡼');
define('ENTRY_EMAIL_ORDER_RECEIVED_REPLY', 'ʧ˥᡼');
define('ENTRY_EMAIL_SOLD_OUT_REPLY', 'Υ᡼');
define('ENTRY_EMAIL_SEND_PRODUCTS_REPLY', 'ʸʧ˥᡼');
define('ENTRY_EMAIL_CODT_PAYMENT_REPLY', '˥᡼');
define('ENTRY_EMAIL_CC_PAYMENT_REPLY', 'ʥ쥸åȡ˥᡼');
define('ENTRY_EMAIL_PENDING_REPLY', '߸˳ǧ᡼');
define('EMAIL_TEXT_RESERVATION', 'ڤ֤ʡ');
define('EMAIL_TEXT_NO_STOCK', 'ڤ쾦ʡ');
define('EMAIL_TEXT_PRODUCTS', '[̾]');
define('EMAIL_TEXT_SUBTITLE', '[]');
define('EMAIL_TEXT_SERIES_TITLE', '[꡼̾]');
define('EMAIL_TEXT_AUTHOR', '[̾]');
define('EMAIL_TEXT_VOLUME', '[]');
define('EMAIL_TEXT_ISBN', '[ISBN]');
define('EMAIL_TEXT_PUBLISHERS', '[Ǹ]');
define('EMAIL_TEXT_PUBLISHED', '[ǯ]');
define('EMAIL_TEXT_DESCRIPTION', '[]');
define('EMAIL_TEXT_MODEL', '[No.]');
define('EMAIL_TEXT_QUANTITY', '[]');
define('EMAIL_TEXT_PRICE', '[]');
define('TEXT_INFO_EMAIL_SEND', 'ʸ̤ǥ᡼ޤ');
?>

==> koshoten.net-2.2.1.tar.gz: koshoten-net/admin/includes/languages/japanese/orders.php <==
<?php
/*
  $Id: orders.php,v 1.2 2005/09/24 12:27:42 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2002 osCommerce

  Released under the GNU General Public License
  
  modified for Koshoten.net2
  http://www.koshoten.net/
*/

define('HEADING_TITLE', 'ʸ');
define('HEADING_TITLE_SEARCH', 'ʸID:');
define('HEADING_TITLE_STATUS', 'ơ:');

define('TABLE_HEADING_COMMENTS', '');
define('TABLE_HEADING_CUSTOMERS', 'ܵ̾');
define('TABLE_HEADING_ORDER_TOTAL', 'ʸ');
define('TABLE_HEADING_DATE_PURCHASED', 'ʸ');
define('TABLE_HEADING_STATUS', 'ơ');
define('TABLE_HEADING_ACTION', '');
define('TABLE_HEADING_QUANTITY', '');
define('TABLE_HEADING_PRODUCTS_MODEL', 'No.');
define('TABLE_HEADING_PRODUCTS', ' /̾');
define('TABLE_HEADING_TAX', 'Ψ');
define('TABLE_HEADING_TOTAL', '');
define('TABLE_HEADING_STATUS', 'ơ');
define('TABLE_HEADING_PRICE_EXCLUDING_TAX', '()');
define('TABLE_HEADING_PRICE_INCLUDING_TAX', '(ǹ)');
define('TABLE_HEADING_TOTAL_EXCLUDING_TAX', '()');
define('TABLE_HEADING_TOTAL_INCLUDING_TAX', '(ǹ)');

define('TABLE_HEADING_STATUS', 'ơ');
define('TABLE_HEADING_CUSTOMER_NOTIFIED', 'ܵҤ');
define('TABLE_HEADING_DATE_ADDED', '');

define('ENTRY_CUSTOMER', 'ܵ̾:');
define('ENTRY_SOLD_TO', 'ʸ̾:');
define('ENTRY_STREET_ADDRESS', '꣱:');
define('ENTRY_SUBURB', 'ꣲ:');
define('ENTRY_CITY', 'ԶĮ¼:');
define('ENTRY_POST_CODE', '͹ֹ:');
define('ENTRY_STATE', 'ƻܸ:');
define('ENTRY_COUNTRY', '̾:');
define('ENTRY_TELEPHONE', 'ֹ:');
define('ENTRY_EMAIL_ADDRESS', 'E-Mail ɥ쥹:');
define('ENTRY_DELIVERY_TO', ':');
define('ENTRY_SHIP_TO', ':');
define('ENTRY_SHIPPING_ADDRESS', ':');
define('ENTRY_BILLING_ADDRESS', ':');
define('ENTRY_PAYMENT_METHOD', 'ʧˡ:');
define('ENTRY_CREDIT_CARD_TYPE', '쥸åȥɼ:');
define('ENTRY_CREDIT_CARD_OWNER', '쥸åȥɽͭ:');
define('ENTRY_CREDIT_CARD_NUMBER', '쥸åȥֹ:');
define('ENTRY_CREDIT_CARD_EXPIRES', '쥸åȥͭ:');
define('ENTRY_SUB_TOTAL', ':');
define('ENTRY_TAX', 'Ƕ:');
define('ENTRY_SHIPPING', ':');
define('ENTRY_TOTAL', ':');
define('ENTRY_DATE_PURCHASED', 'ʸ:');
define('ENTRY_STATUS', 'ơ:');
define('ENTRY_DATE_LAST_UPDATED', ':');
define('ENTRY_NOTIFY_CUSTOMER', 'Ƥ򤪵ͤ˥᡼:');
define('ENTRY_NOTIFY_COMMENTS', 'Ȥɲ:');
define('ENTRY_PRINTABLE', 'Ǽʽץ');

define('TEXT_INFO_HEADING_DELETE_ORDER', 'ʸ');
define('TEXT_INFO_DELETE_INTRO', 'ˤʸޤ?');
define('TEXT_INFO_RESTOCK_PRODUCT_QUANTITY', '߸˿򸵤᤹'); // 'Restock product quantity'
define('TEXT_DATE_ORDER_CREATED', 'ʸ:');
define('TEXT_DATE_ORDER_LAST_MODIFIED', ':');
define('TEXT_INFO_PAYMENT_METHOD', 'ʧˡ:');

define('TEXT_ALL_ORDERS', 'Ƥʸ');
define('TEXT_NO_ORDER_HISTORY', 'ʸϤޤ');

define('EMAIL_SEPARATOR', '--------------------------------------------------------------------------------');
define('EMAIL_TEXT_SUBJECT', 'ʸվΤΤ餻');
define('EMAIL_TEXT_ORDER_NUMBER', 'ʸֹ:');
define('EMAIL_TEXT_INVOICE_URL', 'ʸˤĤƤξ򲼵URLǤˤʤޤ' . "\n");
define('EMAIL_TEXT_DATE_ORDERED', 'ʸ:');
define('EMAIL_TEXT_STATUS_UPDATE',
'ʸμվϼΤ褦ʤäƤޤ' . "\n"
.'ߤμվ: [ %s ]' . "\n\n");
define('EMAIL_TEXT_COMMENTS_UPDATE', '[Ϣ]' . "\n%s");
define('EMAIL_HONORIFIC', ' ');

define('ERROR_ORDER_DOES_NOT_EXIST', '顼: ʸ¸ߤޤ');
define('SUCCESS_ORDER_UPDATED', ': ʸ֤ޤ');
define('WARNING_ORDER_NOT_UPDATED', 'ٹ: ʸ֤ϤʤˤѹޤǤ');

// Add Japanese osCommerce
define('EMAIL_TEXT_STORE_CONFIRMATION', ' ؤΤʸˤ꤬Ȥޤ' . "\n\n"
.'ʸμվڤӤϢ򡢲ˤ⿽夲ޤ');
define('EMAIL_TEXT_STORE_CONFIRMATION_FOOTER', 
'վ˴ؤƤޤ顢ŹˤϢĺޤ褦ꤤ' . "\n"
.'夲ޤ' . "\n\n");

define('ENTRY_EMAIL_ORDER_AUTO_REPLY', 'ưۿ᡼');
define('ENTRY_EMAIL_ORDER_RECEIVED_REPLY', 'ʧ˥᡼');
define('ENTRY_EMAIL_SOLD_OUT_REPLY', 'Υ᡼');
define('ENTRY_EMAIL_SEND_PRODUCTS_REPLY', 'ʸʧ˥᡼');
define('ENTRY_EMAIL_CODT_PAYMENT_REPLY', '˥᡼');
define('ENTRY_EMAIL_CC_PAYMENT_REPLY', 'ʥ쥸åȡ˥᡼');
define('ENTRY_EMAIL_PENDING_REPLY', '߸˳ǧ᡼');
define('EMAIL_TEXT_RESERVATION', 'ڤ֤ʡ');
define('EMAIL_TEXT_NO_STOCK', 'ڤ쾦ʡ');
define('EMAIL_TEXT_PRODUCTS', '[ ̾]');
define('EMAIL_TEXT_SUBTITLE', '[ ]');
define('EMAIL_TEXT_SERIES_TITLE', '[꡼̾]');
define('EMAIL_TEXT_AUTHOR', '[̾]');
define('EMAIL_TEXT_VOLUME', '[ ]');
define('EMAIL_TEXT_ISBN', '[ISBN]');
define('EMAIL_TEXT_PUBLISHERS', '[Ǹ]');
define('EMAIL_TEXT_PUBLISHED', '[ǯ]');
define('EMAIL_TEXT_DESCRIPTION', '[ʸ]');
define('EMAIL_TEXT_MODEL', '[No.]');
define('EMAIL_TEXT_QUANTITY', '[ ]');
define('EMAIL_TEXT_PRICE', '[]');
define('TEXT_INFO_EMAIL_SEND', 'ʸ̤ǥ᡼ޤ');
?>
